<?php

/**
 * Soap-Based service to access the Cdyne Profanity Filter service.
 * For more information {@see http://ws.cdyne.com/ProfanityWS/Profanity.asmx}
 * 
 * Only methods that do no require an API key (and registration) are included in this api
 * 
 * @author Dustin Thomson <dustin.thomson@gmail.com>
 */
class Zext_Service_Cdyne_ProfanityFilter extends Zend_Soap_Client
{
	/**
	 * WSDL that points at the Cdyne Profanity filter services
	 * @var string
	 */
	const WSDL = 'http://ws.cdyne.com/ProfanityWS/Profanity.asmx?WSDL';
	
	/**
	 * Constructor
	 * @param array $options
	 */
	public function __construct($options = array())
	{
		parent::__construct(self::WSDL, $options);
	}
	
	/**
	 * Filters profanity using the advanced filter
	 * @see http://ws.cdyne.com/ProfanityWS/Profanity.asmx?op=AdvancedProfanityFilter
	 * 
	 * Options can contain:
	 *  boolean UseCharacterFilter		[OPTIONAL]	Default True
	 *  boolean UsePhonetics			[OPTIONAL]	Default False
	 *  int		LevelToClean			[OPTIONAL]	Default 0	Level value contains all the levels above it (EG: 0 will include levels 100-0)
	 *  int 	ReplaceProfanityType	[OPTIONAL]	Default 1
	 *  int		UserDefinedLevelsID		[OPTIONAL]	Default 0
	 *  String	ReplaceProfanityText	[OPTIONAL]	Default ''
	 *  String	LicenseKey				[OPTIONAL]	Default ''
	 * @param array $params
	 * @return array Structure containing the method result
	 */
	public function advancedProfanityFilterRemote($text, array $options = array())
	{
		$options = array_merge(array(
			'UseCharacterFilter' => true,
			'UsePhonetics' => false,
			'LevelToClean' => 0,
			'ReplaceProfanityType' => 1,
			'UserDefinedLevelsID' => 0,
			'ReplaceProfanityText' => '',
			'LicenseKey' => ''
		), $options);
		
		$options['Text'] = $text;
		
		$result = $this->AdvancedProfanityFilter(array(
			'Request' => $options
		));
		
		return array(
			'found_profanity' => $result->AdvancedProfanityFilterResult->FoundProfanity,
			'profanity_count' => $result->AdvancedProfanityFilterResult->ProfanityCount,
			'clean_text' => $result->AdvancedProfanityFilterResult->CleanText
		);
	}
	
	/**
	 * Gets the default filtering levels provided by Cdyne
	 * @see http://ws.cdyne.com/ProfanityWS/Profanity.asmx?op=GetDefaultLevels
	 * @return associative array containing the level as key, and description as value
	 */
	public function getDefaultLevelsRemote()
	{
		$result = $this->GetDefaultLevels();
		
		$defaultLevels = array();
		foreach($result->GetDefaultLevelsResult->ProfanityLevel as $levelStruct){
			$defaultLevels[$levelStruct->Level] = $levelStruct->Description;
		}
		
		return $defaultLevels;
	}
	
	/**
	 * Returns a list of default words that will be filered under a given level
	 * @see http://ws.cdyne.com/ProfanityWS/Profanity.asmx?op=GetDefaultWordsByLevel
	 * 
	 * @param int $level
	 * @return array	List of default words
	 */
	public function getDefaultWordsByLevelRemote($level)
	{
		$result = $this->getDefaultWordsByLevel(array(
			'Level' => intval($level)
		));
		
		return $result->GetDefaultWordsByLevelResult->string;
	}
	
	/**
	 * Gets the available replace types that can be used to replace words using
	 * {@link advancedProfanityFilterRemote} method
	 * @see http://ws.cdyne.com/ProfanityWS/Profanity.asmx?op=GetReplaceTypes
	 * 
	 * @return array containing replaceType struct, indexed by replaceType id
	 */
	public function getReplaceTypesRemote()
	{
		$result = $this->GetReplaceTypes();
		
		$replaceTypes = array();
		
		foreach($result->GetReplaceTypesResult->ReplaceType as $replaceStruct){
			$replaceTypes[$replaceStruct->TypeID] = array(
				'type_id' => $replaceStruct->TypeID,
				'example' => $replaceStruct->Example,
				'description' => $replaceStruct->Description
			);
		}
		
		return $replaceTypes;
	}
	
	/**
	 * Regular Profanity Filter, Allows you to specify the level you wish to clean, and this also goes through a number filter to help find cleanse more profanity.
	 * @see http://ws.cdyne.com/ProfanityWS/Profanity.asmx?op=ProfanityFilter
	 * 
	 * @param string	$text	Text to clean
	 * @param int		$level	Level to clean at {@see getDefaultLevelsRemote()}
	 * @param boolean	$numberFilterFlag Flag to indicate if the number filter should be used to find more profanity
	 * @return array Structure containing the method result
	 */
	public function profanityFilterRemote($text, $level, $numberFilterFlag=true)
	{
		$numberFilterFlag = $numberFilterFlag? 'true': 'false';
		
		$result = $this->ProfanityFilter(array(
			'Text' => $text,
			'LevelToClean' => $level,
			'UseNumberFilter' => $numberFilterFlag
		));
		
		return array(
			'found_profanity' => $result->ProfanityFilterResult->FoundProfanity,	
			'profanity_count' => $result->ProfanityFilterResult->ProfanityCount,
			'clean_text' => $result->ProfanityFilterResult->CleanText
		);
	}
	
	/**
	 * Basic Profanity Filter, which replaces curse words with the world [Explicit].
	 * @see http://ws.cdyne.com/ProfanityWS/Profanity.asmx?op=SimpleProfanityFilter
	 * 
	 * @param string $text
	 * @return array Structure containing the method result
	 */
	public function simpleProfanityFilterRemote($text)
	{
		$result = $this->SimpleProfanityFilter(array(
			'Text' => $text
		));
		
		return array(
			'found_profanity' => $result->SimpleProfanityFilterResult->FoundProfanity,	
			'profanity_count' => $result->SimpleProfanityFilterResult->ProfanityCount,
			'clean_text' => $result->SimpleProfanityFilterResult->CleanText
		);;
	}
}